"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createServerless = void 0;
const tslib_1 = require("tslib");
const serverless_1 = tslib_1.__importDefault(require("serverless"));
const resolve_input_1 = tslib_1.__importDefault(require("serverless/lib/cli/resolve-input"));
const getConfiguration_1 = require("./getConfiguration");
const DEFAULT_STAGE = process.env.STAGE;
async function createServerless({ stage = DEFAULT_STAGE } = {}) {
    const { configurationPath, configuration } = await getConfiguration_1.getConfiguration();
    const { commands, options } = resolve_input_1.default();
    const serverless = new serverless_1.default({
        commands,
        options: stage ? { ...options, stage } : options,
        configurationPath,
        configuration,
        stage,
    });
    await serverless.init();
    await setup(serverless);
    if (serverless.invokedInstance) {
        await setup(serverless.invokedInstance);
    }
    return serverless;
}
exports.createServerless = createServerless;
async function setup(serverless) {
    await serverless.variables.populateService(serverless.pluginManager.cliOptions);
    serverless.service.mergeArrays();
    serverless.service.setFunctionNames(serverless.processedInput.options);
}
//# sourceMappingURL=createServerless.js.map