"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runWithEnvVars = void 0;
const tslib_1 = require("tslib");
const chokidar_1 = tslib_1.__importDefault(require("chokidar"));
const path_1 = require("path");
const resolve_configuration_path_1 = tslib_1.__importDefault(require("serverless/lib/cli/resolve-configuration-path"));
const getEnvVars_1 = require("./getEnvVars");
const runChildProcess_1 = require("./runChildProcess");
const setEnvVars_1 = require("./setEnvVars");
async function runWithEnvVars(options) {
    var _a;
    const configPath = (_a = (await resolve_configuration_path_1.default())) !== null && _a !== void 0 ? _a : path_1.join(process.cwd(), 'serverless.yml');
    let cp = await createCp(options);
    if (options.watch) {
        const watcher = chokidar_1.default.watch(configPath, { persistent: true, interval: 1000 });
        watcher.on('change', async () => {
            console.log('Configuration changed, restarting...');
            cp.kill();
            cp = await createCp(options);
        });
    }
}
exports.runWithEnvVars = runWithEnvVars;
async function createCp(options) {
    const { cmd, args, log, stage, watch = false } = options;
    if (log) {
        console.info('Reading Serverless environment variables...');
    }
    const envVars = filterAlreadySetEnvVars(await getEnvVars_1.getEnvVars({ stage }));
    if (log) {
        console.info(`Environment Variables To Set:`);
        console.info(JSON.stringify(envVars, null, 2));
    }
    setEnvVars_1.setEnvVars(envVars, options.namespace);
    if (log) {
        console.info('Serverless environment variables set');
    }
    return runChildProcess_1.runChildProcess(cmd, args, process.env, watch);
}
function filterAlreadySetEnvVars(envVars) {
    const toSet = {};
    for (const key in envVars) {
        if (!(key in process.env)) {
            toSet[key] = envVars[key];
        }
    }
    return toSet;
}
//# sourceMappingURL=runWithEnvVars.js.map